@@ -20,6 +20,7 @@
 #include "plate.hpp"
 #include "sqrdmd.hpp"
 #include "simplexnoise.hpp"
+#include "noise.hpp"
 
 #include <cfloat>
 #include <cmath>
@@ -49,7 +50,6 @@ class plateArea
     size_t hgt; ///< Height of area in pixels.
 };
 
-static const float SQRDMD_ROUGHNESS = 0.5f;
 static const float SUBDUCT_RATIO = 0.5f;
  
 static const float BUOYANCY_BONUS_X = 3;
@@ -64,45 +64,9 @@ size_t findBound(const size_t* map, size_t length, size_t x0, size_t y0,
                  int dx, int dy);
 size_t findPlate(plate** plates, float x, float y, size_t num_plates);
 
-static uint32_t nearest_pow(uint32_t num)
-{
-    uint32_t n = 1;
-
-    while (n < num){
-        n <<= 1;
-    }
-
-    return n;
-}
-
 void lithosphere::createNoise(float* tmp, const WorldDimension& tmpDim, bool useSimplex)
 {
-try {
-    if (useSimplex) {
-        simplexnoise(_randsource(), tmp, 
-            tmpDim.getWidth(), 
-            tmpDim.getHeight(), 
-            SQRDMD_ROUGHNESS);
-    } else {        
-        size_t side = tmpDim.getMax();
-        side = nearest_pow(side)+1;
-        float* squareTmp = new float[side*side];
-        memset(squareTmp, 0, sizeof(float)*side*side);
-        for (int y=0; y<tmpDim.getHeight(); y++){
-            memcpy(&squareTmp[y*side],&tmp[y*tmpDim.getWidth()],sizeof(float)*tmpDim.getWidth());
-        }
-        sqrdmd(_randsource(), squareTmp, side, SQRDMD_ROUGHNESS);
-        for (int y=0; y<tmpDim.getHeight(); y++){
-            memcpy(&tmp[y*tmpDim.getWidth()],&squareTmp[y*side],sizeof(float)*tmpDim.getWidth());
-        }
-        delete[] squareTmp;
-    }    
-} catch (const exception& e){
-    std::string msg = "Problem during lithosphere::createNoise, tmpDim+=";
-    msg = msg + to_string(tmpDim.getWidth()) + "x" + to_string(tmpDim.getHeight()) + " ";
-    msg = msg + e.what();
-    throw runtime_error(msg.c_str());
-}
+    ::createNoise(tmp, tmpDim, _randsource, useSimplex);
 }
 
 lithosphere::lithosphere(long seed, size_t width, size_t height, float sea_level,
@@ -121,7 +85,8 @@ lithosphere::lithosphere(long seed, size_t width, size_t height, float sea_level
     max_plates(0), 
     num_plates(0),
     _worldDimension(width, height),
-    _randsource(seed)
+    _randsource(seed),
+    _steps(0)
 {
     WorldDimension tmpDim = WorldDimension(width+1, height+1);
     const size_t A = tmpDim.getArea();
@@ -366,9 +331,15 @@ float* lithosphere::getTopography() const throw()
     return hmap.raw_data();
 }
 
+bool lithosphere::isFinished() const 
+{
+    return getPlateCount() == 0;
+}
+
 void lithosphere::update()
 {
 try {
+    _steps++;
     float totalVelocity = 0;
     float systemKineticEnergy = 0;
 
@@ -749,7 +720,7 @@ try {
     cycle_count += max_cycles > 0; // No increment if running for ever.
     if (cycle_count > max_cycles)
         return;
-
+    
     // Update height map to include all recent changes.
     hmap.set_all(0);
     for (size_t i = 0; i < num_plates; ++i)
@@ -837,7 +808,7 @@ try {
     // This is the LAST cycle! ////////////////////////////////////////////
     ///////////////////////////////////////////////////////////////////////
 
-    WorldDimension tmpDim = WorldDimension(_worldDimension.getWidth() + 1, _worldDimension.getHeight() + 1);
+    /*WorldDimension tmpDim = WorldDimension(_worldDimension.getWidth() + 1, _worldDimension.getHeight() + 1);
     HeightMap tmp(tmpDim.getWidth(), tmpDim.getHeight());
     float* original = new float[tmpDim.getArea()];
     const size_t line_size = _worldDimension.getWidth() * sizeof(float);
@@ -852,7 +823,7 @@ try {
     }
 
     for (size_t y = 0; y < _worldDimension.getHeight(); y += 8)
-    {
+    {        
         for (size_t x = 0; x < _worldDimension.getWidth(); x += 8)
         {
             size_t i = _worldDimension.indexOf(x, y);
@@ -958,6 +929,10 @@ try {
         h_highest = h_highest > hmap[i] ? h_highest : hmap[i];
     }
 
+    
+    Removing this piece of code because is causing a regular grid of dots
+    polluting square maps not using a side which is a power of 2
+    -----------------------------------------------
     for (size_t y = 0; y < _worldDimension.getHeight(); y += 4)
     {
         for (size_t x = 0; x < _worldDimension.getWidth(); x += 4)
@@ -1019,7 +994,8 @@ try {
             if (original[_worldDimension.indexOf(x, y)] < CONTINENTAL_BASE)
                 hmap[_worldDimension.indexOf(x, y)] = tmp[tmpDim.indexOf(x, y)];
             else
-                hmap[_worldDimension.indexOf(x, y)] = original[_worldDimension.indexOf(x, y)];
+                hmap[_worldDimension.indexOf(x, y)] = original[_worldDimension.indexOf(x, y)];*/
+                
 } catch (const exception& e){
     std::string msg = "Problem during restart: ";
     msg = msg + e.what();
@@ -1037,3 +1013,7 @@ size_t lithosphere::getHeight() const
     return _worldDimension.getHeight();
 }
 
+size_t* lithosphere::getPlatesMap() const throw()
+{
+    return imap;
+}
