@@ -34,7 +34,7 @@
 using namespace std;
 
 plate::plate(long seed, const float* m, size_t w, size_t h, size_t _x, size_t _y,
-             size_t plate_age, WorldDimension worldDimension) throw() :
+             size_t plate_age, WorldDimension worldDimension) :
              _randsource(seed),
              width(w), height(h),
              mass(0), left(_x), top(_y), cx(0), cy(0), dx(0), dy(0),
@@ -94,14 +94,14 @@ plate::~plate() throw()
     segment = NULL;
 }
 
-size_t plate::addCollision(size_t wx, size_t wy) throw()
+size_t plate::addCollision(size_t wx, size_t wy)
 {
     ContinentId seg = getContinentAt(wx, wy);
     ++seg_data[seg].coll_count;
     return seg_data[seg].area;
 }
 
-void plate::addCrustByCollision(size_t x, size_t y, float z, size_t time, ContinentId activeContinent) throw()
+void plate::addCrustByCollision(size_t x, size_t y, float z, size_t time, ContinentId activeContinent)
 {
     // Add crust. Extend plate if necessary.
     setCrust(x, y, getCrust(x, y) + z, time);
@@ -116,7 +116,7 @@ void plate::addCrustByCollision(size_t x, size_t y, float z, size_t time, Contin
 }
 
 void plate::addCrustBySubduction(size_t x, size_t y, float z, size_t t,
-    float dx, float dy) throw()
+    float dx, float dy)
 {
     // TODO: Create an array of coordinate changes that would create
     //       a circle around current point. Array is static and it is
@@ -169,8 +169,9 @@ void plate::addCrustBySubduction(size_t x, size_t y, float z, size_t t,
     }
 }
 
-float plate::aggregateCrust(plate* p, size_t wx, size_t wy) throw()
+float plate::aggregateCrust(plate* p, size_t wx, size_t wy)
 {
+try {    
     size_t lx = wx, ly = wy;
     const size_t index = getMapIndex(&lx, &ly);
     const ContinentId seg_id = segment[index];
@@ -227,9 +228,14 @@ float plate::aggregateCrust(plate* p, size_t wx, size_t wy) throw()
 
     seg_data[seg_id].area = 0; // Mark segment as non-existent
     return old_mass - mass;
+} catch (const exception& e){
+    std::string msg = "Problem during plate::aggregateCrust: ";
+    msg = msg + e.what();
+    throw runtime_error(msg.c_str());
+}
 }
 
-void plate::applyFriction(float deformed_mass) throw()
+void plate::applyFriction(float deformed_mass)
 {
     // Remove the energy that deformation consumed from plate's kinetic
     // energy: F - dF = ma - dF => a = dF/m.
@@ -245,8 +251,9 @@ void plate::applyFriction(float deformed_mass) throw()
     }
 }
 
-void plate::collide(plate& p, size_t wx, size_t wy, float coll_mass) throw()
+void plate::collide(plate& p, size_t wx, size_t wy, float coll_mass)
 {
+try {    
     const float coeff_rest = 0.0; // Coefficient of restitution.
                                   // 1 = fully elastic, 0 = stick together.
 
@@ -357,12 +364,36 @@ void plate::collide(plate& p, size_t wx, size_t wy, float coll_mass) throw()
     // We see that in with restitution 0, both balls continue at same
     // speed along X axis. However at the same time ball B continues its
     // path upwards like it should. Seems correct right?
+} catch (const exception& e){
+    std::string msg = "Problem during plate::collide: ";
+    msg = msg + e.what();
+    throw runtime_error(msg.c_str());
+}
+}
+
+size_t plate::xMod(size_t x) const
+{
+    return (x + _worldDimension.getWidth()) % _worldDimension.getWidth();
+}
+
+size_t plate::yMod(size_t y) const
+{
+    return (y + _worldDimension.getHeight()) % _worldDimension.getHeight();
+}
+
+bool plate::contains(size_t x, size_t y) const
+{
+    size_t cleanX = xMod(x);
+    size_t cleanY = yMod(y);
+
+    return cleanX>=left && cleanX<(left+width) && cleanY>=top && cleanY<(top+height);
 }
 
 void plate::calculateCrust(size_t x, size_t y, size_t index, 
     float& w_crust, float& e_crust, float& n_crust, float& s_crust,
     size_t& w, size_t& e, size_t& n, size_t& s)
 {
+try {    
     // Build masks for accessible directions (4-way).
     // Allow wrapping around map edges if plate has world wide dimensions.
     size_t w_mask = -((x > 0)          | (width == _worldDimension.getWidth()));
@@ -373,10 +404,10 @@ void plate::calculateCrust(size_t x, size_t y, size_t index,
     // Calculate the x and y offset of neighbour directions.
     // If neighbour is out of plate edges, set it to zero. This protects
     // map memory reads from segment faulting.
-    w = (_worldDimension.getWidth()  + x - 1) & (_worldDimension.getWidth()  - 1) & w_mask;
-    e = (_worldDimension.getWidth()  + x + 1) & (_worldDimension.getWidth()  - 1) & e_mask;
-    n = (_worldDimension.getHeight() + y - 1) & (_worldDimension.getHeight() - 1) & n_mask;
-    s = (_worldDimension.getHeight() + y + 1) & (_worldDimension.getHeight() - 1) & s_mask;
+    w = w_mask==-1 ? xMod(x-1) : 0;
+    e = e_mask==-1 ? xMod(x+1) : 0;
+    n = n_mask==-1 ? yMod(y-1) : 0;
+    s = s_mask==-1 ? yMod(y+1) : 0;
 
     // Calculate offsets within map memory.
     w = y * width + w;
@@ -389,10 +420,22 @@ void plate::calculateCrust(size_t x, size_t y, size_t index,
     e_crust = map[e] * (e_mask & (map[e] < map[index]));
     n_crust = map[n] * (n_mask & (map[n] < map[index]));
     s_crust = map[s] * (s_mask & (map[s] < map[index]));    
+} catch (const exception& e){
+    std::string msg = "Problem during plate::calculateCrust (width: ";
+    msg = msg + to_string(width)
+            + ", height: " + to_string(height) 
+            + ", left: " + to_string(left) 
+            + ", top: " + to_string(top) 
+            + ", x: " + to_string(x)
+            + ", y:" + to_string(y) + ") :"
+            + e.what();
+    throw runtime_error(msg.c_str());
+}
 }
 
-void plate::erode(float lower_bound) throw()
+void plate::erode(float lower_bound)
 {
+try {    
   vector<size_t> sources_data;
   vector<size_t> sinks_data;
   vector<size_t>* sources = &sources_data;
@@ -615,9 +658,14 @@ void plate::erode(float lower_bound) throw()
     cx /= mass;
     cy /= mass;
   }
+} catch (const exception& e){
+    std::string msg = "Problem during plate::erode: ";
+    msg = msg + e.what();
+    throw runtime_error(msg.c_str());
+}
 }
 
-void plate::getCollisionInfo(size_t wx, size_t wy, size_t* count, float* ratio) const throw()
+void plate::getCollisionInfo(size_t wx, size_t wy, size_t* count, float* ratio) const
 {
     ContinentId seg = getContinentAt(wx, wy);
 
@@ -629,7 +677,7 @@ void plate::getCollisionInfo(size_t wx, size_t wy, size_t* count, float* ratio)
         (float)(1 + seg_data[seg].area); // +1 avoids DIV with zero.
 }
 
-size_t plate::getContinentArea(size_t wx, size_t wy) const throw()
+size_t plate::getContinentArea(size_t wx, size_t wy) const
 {
     const size_t index = getMapIndex(&wx, &wy);
 
@@ -638,19 +686,19 @@ size_t plate::getContinentArea(size_t wx, size_t wy) const throw()
     return seg_data[segment[index]].area;
 }
 
-float plate::getCrust(size_t x, size_t y) const throw()
+float plate::getCrust(size_t x, size_t y) const
 {
     const size_t index = getMapIndex(&x, &y);
     return index < (size_t)(-1) ? map[index] : 0;
 }
 
-size_t plate::getCrustTimestamp(size_t x, size_t y) const throw()
+size_t plate::getCrustTimestamp(size_t x, size_t y) const
 {
     const size_t index = getMapIndex(&x, &y);
     return index < (size_t)(-1) ? age_map[index] : 0;
 }
 
-void plate::getMap(const float** c, const size_t** t) const throw()
+void plate::getMap(const float** c, const size_t** t) const
 {
     if (c) {
         *c = map.raw_data();
@@ -660,8 +708,9 @@ void plate::getMap(const float** c, const size_t** t) const throw()
     }
 }
 
-void plate::move() throw()
+void plate::move()
 {
+try {    
     float len;
 
     // Apply any new impulses to the plate's trajectory.
@@ -704,16 +753,22 @@ void plate::move() throw()
     top -= top < _worldDimension.getHeight() ? 0 : _worldDimension.getHeight();
 
     assert(_worldDimension.contains(left, top));
+} catch (const exception& e){
+    std::string msg = "Problem during plate::move: ";
+    msg = msg + e.what();
+    throw runtime_error(msg.c_str());
+}
 }
 
-void plate::resetSegments() throw()
+void plate::resetSegments()
 {
     memset(segment, -1, sizeof(size_t) * width * height);
     seg_data.clear();
 }
 
-void plate::setCrust(size_t x, size_t y, float z, size_t t) throw()
+void plate::setCrust(size_t x, size_t y, float z, size_t t)
 {
+try {    
     if (z < 0) { // Do not accept negative values.
         z = 0;
     }
@@ -829,9 +884,14 @@ void plate::setCrust(size_t x, size_t y, float z, size_t t) throw()
     mass -= map[index];
     map[index] = z;     // Set new crust height to desired location.
     mass += z;      // Update mass counter.
+} catch (const exception& e){
+    std::string msg = "Problem during plate::setCrust: ";
+    msg = msg + e.what();
+    throw runtime_error(msg.c_str());
+}
 }
 
-ContinentId plate::selectCollisionSegment(size_t coll_x, size_t coll_y) throw()
+ContinentId plate::selectCollisionSegment(size_t coll_x, size_t coll_y)
 {
     size_t index = getMapIndex(&coll_x, &coll_y);
     ContinentId activeContinent = segment[index];
@@ -844,6 +904,7 @@ ContinentId plate::selectCollisionSegment(size_t coll_x, size_t coll_y) throw()
 
 size_t plate::createSegment(size_t x, size_t y) throw()
 {
+try {    
     const size_t origin_index = y * width + x;
     const size_t ID = seg_data.size();
 
@@ -1060,6 +1121,11 @@ size_t plate::createSegment(size_t x, size_t y) throw()
     seg_data.push_back(data);
 
     return ID;
+} catch (const exception& e){
+    std::string msg = "Problem during plate::createSegement: ";
+    msg = msg + e.what();
+    throw runtime_error(msg.c_str());
+}
 }
 
 size_t plate::getMapIndex(size_t* px, size_t* py) const throw()
